==> java-cxf-spring-server-generator-0.10.0.tgz: package/test-output/operations-v2.yml/src/main/java/com/example/impl/Test2ApiImpl.java <==
package com.example.impl;

@javax.ws.rs.Path("/test2")
@org.springframework.stereotype.Service("Test2Api")
@io.swagger.annotations.Api(description = "the Test2 API")
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2020-12-14T23:24:37.064Z")
public class Test2ApiImpl implements com.example.Test2Api {

	@org.springframework.beans.factory.annotation.Autowired
	private com.example.service.Test2ApiService delegate;

	private javax.validation.ValidatorFactory validatorFactory = javax.validation.Validation.buildDefaultValidatorFactory();

	public javax.ws.rs.core.Response postTest2(com.example.model.PostTest2A a) {
		final javax.ws.rs.core.Response.ResponseBuilder __response = javax.ws.rs.core.Response.status(201).cacheControl(javax.ws.rs.core.CacheControl.valueOf("no-cache, no-store, must-revalidate, private"));
		try {
			if (a != null) {
				java.util.Set<javax.validation.ConstraintViolation<com.example.model.PostTest2A>> __validations = this.validatorFactory.getValidator().validate(a);
				if (!__validations.isEmpty()) {
					return __response
						.status(javax.ws.rs.core.Response.Status.BAD_REQUEST)
						.type(javax.ws.rs.core.MediaType.TEXT_PLAIN_TYPE)
						.entity(__validations.stream()
							.map(__v -> __v.getPropertyPath() + " " + __v.getMessage())
							.collect(java.util.stream.Collectors.toList()))
						.build();
				}
			}
			
			this.delegate.postTest2(a, __response);
			return __response.build();
		} finally {
		
		}
	}

}

==> java-cxf-spring-server-generator-0.10.1.tgz: package/test-output/operations-v2.yml/src/main/java/com/example/impl/Test2ApiImpl.java <==
package com.example.impl;

@javax.ws.rs.Path("/test2")
@org.springframework.stereotype.Service("Test2Api")
@io.swagger.annotations.Api(description = "the Test2 API")
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2020-12-23T00:05:55.395Z")
public class Test2ApiImpl implements com.example.Test2Api {

	@org.springframework.beans.factory.annotation.Autowired
	private com.example.service.Test2ApiService delegate;

	private javax.validation.ValidatorFactory validatorFactory = javax.validation.Validation.buildDefaultValidatorFactory();

	public javax.ws.rs.core.Response postTest2(com.example.model.PostTest2A a) {
		final javax.ws.rs.core.Response.ResponseBuilder __response = javax.ws.rs.core.Response.status(201).cacheControl(javax.ws.rs.core.CacheControl.valueOf("no-cache, no-store, must-revalidate, private"));
		try {
			if (a != null) {
				java.util.Set<javax.validation.ConstraintViolation<com.example.model.PostTest2A>> __validations = this.validatorFactory.getValidator().validate(a);
				if (!__validations.isEmpty()) {
					return __response
						.status(javax.ws.rs.core.Response.Status.BAD_REQUEST)
						.type(javax.ws.rs.core.MediaType.TEXT_PLAIN_TYPE)
						.entity(__validations.stream()
							.map(__v -> __v.getPropertyPath() + " " + __v.getMessage())
							.collect(java.util.stream.Collectors.joining("\n")))
						.build();
				}
			}
			
			this.delegate.postTest2(a, __response);
			return __response.build();
		} finally {
		
		}
	}

}
